==> plasma-workspace-5.23.5-4.src.tar.gz: plasma-workspace-5.23.5/login-sessions/plasmawayland-dev.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_FULL_LIBEXECDIR@/plasma-dbus-run-session-if-needed @CMAKE_INSTALL_FULL_LIBEXECDIR@/startplasma-dev.sh -wayland
DesktopNames=KDE
Name=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ar]=بلازما (تطوير, ويلاند ${CMAKE_INSTALL_FULL_BINDIR})
Name[ast]=Plasma (Desendolcu, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[az]=Plasma (Tərtib mərhələsində olan Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ca]=Plasma (Desenvolupament, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[da]=Plasma (udvikling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[de]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[en_GB]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[es]=Plasma (Desarrollo, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[et]=Plasma (arendus, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[eu]=Plasma (Garapena, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[fi]=Plasma (kehitys, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[fr]=Plasma (Développement, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[gl]=Plasma (desenvolvemento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[hi]=प्लाज़्मा (विकास, वैलेंड ${CMAKE_INSTALL_FULL_BINDIR})
Name[hu]=Plasma (Fejlesztői verzió, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ia]=Plasma (Disveloppamento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[id]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[it]=Plasma (Sviluppo, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ko]=Plasma(개발, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[lt]=Plasma (Plėtojimas, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ml]=പ്ലാസ്മ (വികസനം, വേലാൻഡ് ${CMAKE_INSTALL_FULL_BINDIR})
Name[nl]=Plasma (Ontwikkeling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[nn]=Plasma (utvikling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[pa]=ਪਲਾਜ਼ਮਾ (ਡਿਵੈਲਪਮੈਂਟ, ਵੇਅਲੈਂਡ ${CMAKE_INSTALL_FULL_BINDIR})
Name[pl]=Plazma (Rozwój , Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[pt]=Plasma (Desenvolvimento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[pt_BR]=Plasma (Desenvolvimento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ro]=Plasma (Dezvoltare, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ru]=Plasma (разрабатываемая версия, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[sk]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[sl]=Plasma (Razvoj, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[sv]=Plasma (utveckling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[tr]=Plasma (Geliştirme, Wayland $ {CMAKE_INSTALL_FULL_BINDIR})
Name[uk]=Плазма (Розробка, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[vi]=Plasma (Phát triển, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[x-test]=xxPlasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})xx
Name[zh_CN]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[zh_TW]=Plasma (開發版本，Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Comment=Plasma by KDE
Comment[ar]=بلازما كدي
Comment[ast]=Plasma por KDE
Comment[az]=KDE Plasma
Comment[bs]=Plazma od strane KDe
Comment[ca]=Plasma, creat per la comunitat KDE
Comment[ca@valencia]=Plasma, creat per la comunitat KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[es]=Plasma, por KDE
Comment[et]=KDE Plasma
Comment[eu]=KDEren Plasma
Comment[fi]=Plasma KDE:ltä
Comment[fr]=Plasma, par KDE
Comment[gl]=Plasma, fornecido por KDE.
Comment[he]=פלזמה באמצעות KDE
Comment[hi]=केडीइ द्वारा प्लाज़्मा
Comment[hsb]=Plasma wot KDE
Comment[hu]=Plasma a KDE-től
Comment[ia]=Plasma per KDE
Comment[id]=Plasma oleh KDE
Comment[is]=Plasma frá KDE
Comment[it]=Plasma di KDE
Comment[ja]=Plasma by KDE
Comment[ko]=KDE Plasma
Comment[lt]=Plasma pagal KDE
Comment[ml]=കെഡിഇയുടെ പ്ലാസ്മ
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[nn]=Plasma frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ro]=Plasma, de către KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[ta]=கே.டீ.யீ. வழங்கும் பிளாஸ்மா
Comment[tg]=Plasma аз ҷониби KDE
Comment[tr]=KDE Plasma
Comment[uk]=Плазма KDE
Comment[vi]=Plasma, do KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE Plasma
Comment[zh_TW]=Plasma by KDE
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-workspace-5.27.10-2.2.src.tar.gz: plasma-workspace-5.27.10/login-sessions/plasmawayland-dev.desktop.cmake <==
[Desktop Entry]
Exec=@CMAKE_INSTALL_FULL_LIBEXECDIR@/plasma-dbus-run-session-if-needed @CMAKE_INSTALL_FULL_LIBEXECDIR@/startplasma-dev.sh -wayland
DesktopNames=KDE
Name=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ar]=بلازما (تطوير, ويلاند ${CMAKE_INSTALL_FULL_BINDIR})
Name[az]=Plasma (Tərtib mərhələsində olan Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[be]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[bg]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ca]=Plasma (Desenvolupament, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ca@valencia]=Plasma (Desenvolupament, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[da]=Plasma (udvikling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[de]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[en_GB]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[eo]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[es]=Plasma (Desarrollo, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[et]=Plasma (arendus, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[eu]=Plasma (Garapena, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[fi]=Plasma (kehitys, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[fr]=Plasma (Développement, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[gl]=Plasma (desenvolvemento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[hi]=प्लाज़्मा (विकास, वैलेंड ${CMAKE_INSTALL_FULL_BINDIR})
Name[hu]=Plasma (Fejlesztői verzió, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ia]=Plasma (Disveloppamento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[id]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[is]=Plasma (Þróunarútgáfa, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[it]=Plasma (Sviluppo, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ja]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ka]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ko]=Plasma(개발, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[lt]=Plasma (Plėtojimas, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ml]=പ്ലാസ്മ (വികസനം, വേലാൻഡ് ${CMAKE_INSTALL_FULL_BINDIR})
Name[nl]=Plasma (Ontwikkeling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[nn]=Plasma (utvikling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[pa]=ਪਲਾਜ਼ਮਾ (ਡਿਵੈਲਪਮੈਂਟ, ਵੇਅਲੈਂਡ ${CMAKE_INSTALL_FULL_BINDIR})
Name[pl]=Plazma (Rozwój , Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[pt]=Plasma (Desenvolvimento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[pt_BR]=Plasma (Desenvolvimento, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ro]=Plasma (Dezvoltare, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ru]=Plasma (разрабатываемая версия, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[sk]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[sl]=Plasma (Razvoj, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[sv]=Plasma (utveckling, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[ta]=பிளாஸ்மா (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[tr]=Plasma (Geliştirme, Wayland $ {CMAKE_INSTALL_FULL_BINDIR})
Name[uk]=Плазма (Розробка, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[vi]=Plasma (Phát triển, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[x-test]=xxPlasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})xx
Name[zh_CN]=Plasma (Development, Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Name[zh_TW]=Plasma (開發版本，Wayland ${CMAKE_INSTALL_FULL_BINDIR})
Comment=Plasma by KDE
Comment[ar]=بلازما كِيدِي
Comment[az]=KDE Plasma
Comment[be]=Plasma KDE
Comment[bg]=Plasma от KDE
Comment[bs]=Plazma od strane KDe
Comment[ca]=Plasma, creat per la comunitat KDE
Comment[ca@valencia]=Plasma, creat per la comunitat KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[eo]=Plasma de KDE
Comment[es]=Plasma, por KDE
Comment[et]=KDE Plasma
Comment[eu]=KDEren Plasma
Comment[fi]=Plasma KDE:ltä
Comment[fr]=Plasma, par KDE
Comment[gl]=Plasma, fornecido por KDE.
Comment[he]=פלזמה באמצעות KDE
Comment[hi]=केडीइ द्वारा प्लाज़्मा
Comment[hsb]=Plasma wot KDE
Comment[hu]=Plasma a KDE-től
Comment[ia]=Plasma per KDE
Comment[id]=Plasma oleh KDE
Comment[is]=Plasma frá KDE
Comment[it]=Plasma di KDE
Comment[ja]=Plasma by KDE
Comment[ka]=Plasma, KDE-სგან
Comment[ko]=KDE Plasma
Comment[lt]=Plasma pagal KDE
Comment[ml]=കെഡിഇയുടെ പ്ലാസ്മ
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[nn]=Plasma frå KDE
Comment[pa]=KDE ਵਲੋਂ ਪਲਾਜ਼ਮਾ
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ro]=Plasma, de către KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[ta]=கே.டீ.யீ. வழங்கும் பிளாஸ்மா
Comment[tg]=Plasma аз ҷониби KDE
Comment[tr]=KDE Plasma
Comment[uk]=Плазма KDE
Comment[vi]=Plasma, do KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE Plasma
Comment[zh_TW]=Plasma by KDE
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
